@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -138,6 +141,42 @@ class DataprocMetastoreAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return DataprocMetastoreClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> DataprocMetastoreTransport:
         """Returns the transport used by the client instance.
@@ -209,6 +248,26 @@ class DataprocMetastoreAsyncClient:
     ) -> pagers.ListServicesAsyncPager:
         r"""Lists services in a project and location.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_list_services():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ListServicesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_services(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ListServicesRequest, dict]):
                 The request object. Request message for
@@ -238,7 +297,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -291,6 +350,25 @@ class DataprocMetastoreAsyncClient:
     ) -> metastore.Service:
         r"""Gets the details of a single service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_get_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.GetServiceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_service(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.GetServiceRequest, dict]):
                 The request object. Request message for
@@ -317,7 +395,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -367,6 +445,31 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a metastore service in a project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_create_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.CreateServiceRequest(
+                    parent="parent_value",
+                    service_id="service_id_value",
+                )
+
+                # Make the request
+                operation = client.create_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.CreateServiceRequest, dict]):
                 The request object. Request message for
@@ -420,7 +523,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, service, service_id])
         if request is not None and has_flattened_params:
@@ -480,6 +583,28 @@ class DataprocMetastoreAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_update_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.UpdateServiceRequest(
+                )
+
+                # Make the request
+                operation = client.update_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.UpdateServiceRequest, dict]):
                 The request object. Request message for
@@ -521,7 +646,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([service, update_mask])
         if request is not None and has_flattened_params:
@@ -580,6 +705,29 @@ class DataprocMetastoreAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_delete_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.DeleteServiceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.DeleteServiceRequest, dict]):
                 The request object. Request message for
@@ -619,7 +767,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -674,6 +822,26 @@ class DataprocMetastoreAsyncClient:
     ) -> pagers.ListMetadataImportsAsyncPager:
         r"""Lists imports in a service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_list_metadata_imports():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ListMetadataImportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_metadata_imports(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ListMetadataImportsRequest, dict]):
                 The request object. Request message for
@@ -703,7 +871,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -756,6 +924,25 @@ class DataprocMetastoreAsyncClient:
     ) -> metastore.MetadataImport:
         r"""Gets details of a single import.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_get_metadata_import():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.GetMetadataImportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_metadata_import(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.GetMetadataImportRequest, dict]):
                 The request object. Request message for
@@ -782,7 +969,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -832,6 +1019,31 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a new MetadataImport in a given project and
         location.
 
+
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_create_metadata_import():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.CreateMetadataImportRequest(
+                    parent="parent_value",
+                    metadata_import_id="metadata_import_id_value",
+                )
+
+                # Make the request
+                operation = client.create_metadata_import(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.CreateMetadataImportRequest, dict]):
                 The request object. Request message for
@@ -884,7 +1096,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, metadata_import, metadata_import_id])
         if request is not None and has_flattened_params:
@@ -946,6 +1158,29 @@ class DataprocMetastoreAsyncClient:
         Only the description field of MetadataImport is
         supported to be updated.
 
+
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_update_metadata_import():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.UpdateMetadataImportRequest(
+                )
+
+                # Make the request
+                operation = client.update_metadata_import(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.UpdateMetadataImportRequest, dict]):
                 The request object. Request message for
@@ -987,7 +1222,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([metadata_import, update_mask])
         if request is not None and has_flattened_params:
@@ -1045,6 +1280,30 @@ class DataprocMetastoreAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Exports metadata from a service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_export_metadata():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ExportMetadataRequest(
+                    destination_gcs_folder="destination_gcs_folder_value",
+                    service="service_value",
+                )
+
+                # Make the request
+                operation = client.export_metadata(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ExportMetadataRequest, dict]):
                 The request object. Request message for
@@ -1107,6 +1366,30 @@ class DataprocMetastoreAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Restores a service from a backup.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_restore_service():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.RestoreServiceRequest(
+                    service="service_value",
+                    backup="backup_value",
+                )
+
+                # Make the request
+                operation = client.restore_service(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.RestoreServiceRequest, dict]):
                 The request object. Request message for
@@ -1145,7 +1428,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([service, backup])
         if request is not None and has_flattened_params:
@@ -1202,6 +1485,26 @@ class DataprocMetastoreAsyncClient:
     ) -> pagers.ListBackupsAsyncPager:
         r"""Lists backups in a service.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_list_backups():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.ListBackupsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_backups(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.ListBackupsRequest, dict]):
                 The request object. Request message for
@@ -1231,7 +1534,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1284,6 +1587,25 @@ class DataprocMetastoreAsyncClient:
     ) -> metastore.Backup:
         r"""Gets details of a single backup.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_get_backup():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.GetBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_backup(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.GetBackupRequest, dict]):
                 The request object. Request message for
@@ -1308,7 +1630,7 @@ class DataprocMetastoreAsyncClient:
                 The details of a backup resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1357,6 +1679,30 @@ class DataprocMetastoreAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new backup in a given project and location.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_create_backup():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.CreateBackupRequest(
+                    parent="parent_value",
+                    backup_id="backup_id_value",
+                )
+
+                # Make the request
+                operation = client.create_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.CreateBackupRequest, dict]):
                 The request object. Request message for
@@ -1407,7 +1753,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, backup, backup_id])
         if request is not None and has_flattened_params:
@@ -1466,6 +1812,29 @@ class DataprocMetastoreAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single backup.
 
+        .. code-block:: python
+
+            from google.cloud import metastore_v1
+
+            def sample_delete_backup():
+                # Create a client
+                client = metastore_v1.DataprocMetastoreClient()
+
+                # Initialize request argument(s)
+                request = metastore_v1.DeleteBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.metastore_v1.types.DeleteBackupRequest, dict]):
                 The request object. Request message for
@@ -1505,7 +1874,7 @@ class DataprocMetastoreAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
