@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,12 +15,14 @@
 #
 
 from .services.dataproc_metastore import DataprocMetastoreClient
+from .services.dataproc_metastore import DataprocMetastoreAsyncClient
+
 from .types.metastore import Backup
 from .types.metastore import CreateBackupRequest
 from .types.metastore import CreateMetadataImportRequest
 from .types.metastore import CreateServiceRequest
-from .types.metastore import DataCatalogConfig
 from .types.metastore import DatabaseDumpSpec
+from .types.metastore import DataCatalogConfig
 from .types.metastore import DeleteBackupRequest
 from .types.metastore import DeleteServiceRequest
 from .types.metastore import ExportMetadataRequest
@@ -50,14 +51,15 @@ from .types.metastore import Service
 from .types.metastore import UpdateMetadataImportRequest
 from .types.metastore import UpdateServiceRequest
 
-
 __all__ = (
+    "DataprocMetastoreAsyncClient",
     "Backup",
     "CreateBackupRequest",
     "CreateMetadataImportRequest",
     "CreateServiceRequest",
     "DataCatalogConfig",
     "DatabaseDumpSpec",
+    "DataprocMetastoreClient",
     "DeleteBackupRequest",
     "DeleteServiceRequest",
     "ExportMetadataRequest",
@@ -85,5 +87,4 @@ __all__ = (
     "Service",
     "UpdateMetadataImportRequest",
     "UpdateServiceRequest",
-    "DataprocMetastoreClient",
 )
